Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(245)

Unified Diff: src/objects.h

Issue 2598543003: [runtime][ic] Constant field tracking support. (Closed)
Patch Set: Addressing comments Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/map-updater.cc ('k') | src/objects.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index d76ffde41fba5bb2f2e27cab24f967696c67cfe2..3f10597d62bb578967a81aa8bed0c0afb83925b1 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -3195,7 +3195,8 @@ class DescriptorArray: public FixedArray {
PropertyDetails details);
void Replace(int descriptor_number, Descriptor* descriptor);
// Generalizes representation and field type of all field descriptors.
void GeneralizeAllFields();
// Append automatically sets the enumeration index. This should only be used
@@ -5941,6 +5942,7 @@ class Map: public HeapObject {
Representation rep1, Handle<FieldType> type1, Representation rep2,
Handle<FieldType> type2, Isolate* isolate);
static void GeneralizeField(Handle<Map> map, int modify_index,
+ PropertyConstness new_constness,
Representation new_representation,
Handle<FieldType> new_field_type);
@@ -5955,6 +5957,7 @@ class Map: public HeapObject {
static Handle<Map> PrepareForDataProperty(Handle<Map> old_map,
int descriptor_number,
+ PropertyConstness constness,
Handle<Object> value);
static Handle<Map> Normalize(Handle<Map> map, PropertyNormalizationMode mode,
@@ -6079,8 +6082,8 @@ class Map: public HeapObject {
MUST_USE_RESULT static MaybeHandle<Map> CopyWithField(
Handle<Map> map, Handle<Name> name, Handle<FieldType> type,
- PropertyAttributes attributes, Representation representation,
- TransitionFlag flag);
+ PropertyAttributes attributes, PropertyConstness constness,
+ Representation representation, TransitionFlag flag);
MUST_USE_RESULT static MaybeHandle<Map> CopyWithConstant(
Handle<Map> map,
@@ -6121,6 +6124,7 @@ class Map: public HeapObject {
Handle<Name> name,
Handle<Object> value,
PropertyAttributes attributes,
+ PropertyConstness constness,
StoreFromKeyed store_mode);
static Handle<Map> TransitionToAccessorProperty(
Isolate* isolate, Handle<Map> map, Handle<Name> name, int descriptor,
@@ -6412,6 +6416,7 @@ class Map: public HeapObject {
// type. The type must be prepared for storing in descriptor array:
// it must be either a simple type or a map wrapped in a weak cell.
void UpdateFieldType(int descriptor_number, Handle<Name> name,
+ PropertyConstness new_constness,
Representation new_representation,
Handle<Object> new_wrapped_type);
« no previous file with comments | « src/map-updater.cc ('k') | src/objects.cc » ('j') | no next file with comments »
@@ -3195,7 +3195,8 @@ class DescriptorArray: public FixedArray {
PropertyDetails details);
void Replace(int descriptor_number, Descriptor* descriptor);
- // Generalizes representation and field type of all field descriptors.
+ // Generalizes constness, representation and field type of all field
+ // descriptors.
void GeneralizeAllFields();
// Append automatically sets the enumeration index. This should only be used

Powered by Google App Engine
This is Rietveld 408576698